@@ -46,10 +46,12 @@ class CondaChannel(BaseModel):
 class CondaPackage(BaseModel):
     id: int
     channel_id: int
+    build: str
     license: Optional[str]
     sha256: str
     name: str
     version: str
+    summary: Optional[str]
 
     class Config:
         orm_mode = True
@@ -76,7 +78,7 @@ class Specification(BaseModel):
 
 class Build(BaseModel):
     id: int
-    namespace: Namespace
+    environment_id: int
     specification: Specification
     packages: List[CondaPackage]
     status: enum.Enum
@@ -94,8 +96,8 @@ class Environment(BaseModel):
     id: int
     namespace: Namespace
     name: str
-    build_id: Optional[int]
-    build: Optional[Build]
+    current_build_id: int
+    current_build: Build
 
     class Config:
         orm_mode = True
