@@ -28,10 +28,14 @@ ARN_ALLOWED_REGEX = re.compile(
 
 
 class Permissions(enum.Enum):
-    ENVIRONMENT_CREATE = "build::create"
-    ENVIRONMENT_READ = "build::read"
-    ENVIRONMENT_UPDATE = "build::update"
-    ENVIRONMENT_DELETE = "build::delete"
+    ENVIRONMENT_CREATE = "environment:create"
+    ENVIRONMENT_READ = "environment::read"
+    ENVIRONMENT_UPDATE = "environment::update"
+    ENVIRONMENT_DELETE = "environment::delete"
+    BUILD_DELETE = "build::delete"
+    NAMESPACE_CREATE = "namespace::create"
+    NAMESPACE_READ = "namespace::read"
+    NAMESPACE_DELETE = "namespace::delete"
 
 
 class AuthenticationBackend(LoggingConfigurable):
@@ -67,17 +71,25 @@ class AuthenticationBackend(LoggingConfigurable):
 class RBACAuthorizationBackend(LoggingConfigurable):
     role_mappings = Dict(
         {
-            "viewer": {Permissions.ENVIRONMENT_READ},
+            "viewer": {
+                Permissions.ENVIRONMENT_READ,
+                Permissions.NAMESPACE_READ,
+            },
             "developer": {
                 Permissions.ENVIRONMENT_CREATE,
                 Permissions.ENVIRONMENT_READ,
                 Permissions.ENVIRONMENT_UPDATE,
+                Permissions.NAMESPACE_READ,
             },
             "admin": {
+                Permissions.BUILD_DELETE,
                 Permissions.ENVIRONMENT_CREATE,
+                Permissions.ENVIRONMENT_DELETE,
                 Permissions.ENVIRONMENT_READ,
                 Permissions.ENVIRONMENT_UPDATE,
-                Permissions.ENVIRONMENT_DELETE,
+                Permissions.NAMESPACE_CREATE,
+                Permissions.NAMESPACE_DELETE,
+                Permissions.NAMESPACE_READ,
             },
         },
         help="default role to permissions mapping to use",
@@ -102,11 +114,20 @@ class RBACAuthorizationBackend(LoggingConfigurable):
 
     @staticmethod
     def compile_arn_regex(arn):
-        """Take an arn of form "example-*/example-*" and compile to regular expression"""
+        """Take an arn of form "example-*/example-*" and compile to regular expression
+
+        The expression "example-*/example-*" will match:
+          - "example-asdf"
+          - "example-asdf/example-qwer"
+        """
         if not ARN_ALLOWED_REGEX.match(arn):
             raise ValueError(f"invalid arn={arn}")
 
-        regex_arn = "^" + re.sub(r"\*", r"[A-Za-z0-9_\-\.|<>=]*", arn) + "$"
+        # replace "*" with "[A-Za-z0-9_\-\.|<>=]*"
+        arn = re.sub(r"\*", r"[A-Za-z0-9_\-\.|<>=]*", arn)
+
+        namespace_regex, name_regex = arn.split("/")
+        regex_arn = "^" + namespace_regex + "(?:/" + name_regex + ")?$"
         return re.compile(regex_arn)
 
     @staticmethod
@@ -308,7 +329,7 @@ class Authentication(LoggingConfigurable):
             cases.append(
                 and_(
                     orm.Namespace.name.like(namespace),
-                    orm.Specification.name.like(name),
+                    orm.Environment.name.like(name),
                 )
             )
 
@@ -316,8 +337,8 @@ class Authentication(LoggingConfigurable):
             return query.filter(False)
 
         return (
-            query.join(orm.Build.namespace)
-            .join(orm.Build.specification)
+            query.join(orm.Build.environment)
+            .join(orm.Environment.namespace)
             .filter(or_(*cases))
         )
 
